from setuptools import setup, find_packages

setup(
    name='meru_app',
    version='1.0.0',
    description='Meru Python API',
    packages=find_packages(),
    install_requires=[
        # List your dependencies here
    ]
)
